@@ -3,9 +3,11 @@ from .collate import collate
 from .data_container import DataContainer
 from .data_parallel import MMDataParallel
 from .distributed import MMDistributedDataParallel
+from .registry import MODULE_WRAPPERS
 from .scatter_gather import scatter, scatter_kwargs
+from .utils import is_module_wrapper
 
 __all__ = [
     'collate', 'DataContainer', 'MMDataParallel', 'MMDistributedDataParallel',
-    'scatter', 'scatter_kwargs'
+    'scatter', 'scatter_kwargs', 'is_module_wrapper', 'MODULE_WRAPPERS'
 ]
