@@ -3,16 +3,17 @@ from .checkpoint import CheckpointHook
 from .closure import ClosureHook
 from .hook import HOOKS, Hook
 from .iter_timer import IterTimerHook
-from .logger import (LoggerHook, PaviLoggerHook, TensorboardLoggerHook,
-                     TextLoggerHook, WandbLoggerHook)
+from .logger import (LoggerHook, MlflowLoggerHook, PaviLoggerHook,
+                     TensorboardLoggerHook, TextLoggerHook, WandbLoggerHook)
 from .lr_updater import LrUpdaterHook
 from .memory import EmptyCacheHook
+from .momentum_updater import MomentumUpdaterHook
 from .optimizer import OptimizerHook
 from .sampler_seed import DistSamplerSeedHook
 
 __all__ = [
     'HOOKS', 'Hook', 'CheckpointHook', 'ClosureHook', 'LrUpdaterHook',
     'OptimizerHook', 'IterTimerHook', 'DistSamplerSeedHook', 'EmptyCacheHook',
-    'LoggerHook', 'PaviLoggerHook', 'TextLoggerHook', 'TensorboardLoggerHook',
-    'WandbLoggerHook'
+    'LoggerHook', 'MlflowLoggerHook', 'PaviLoggerHook', 'TextLoggerHook',
+    'TensorboardLoggerHook', 'WandbLoggerHook', 'MomentumUpdaterHook'
 ]
