@@ -2,7 +2,7 @@
 from .hook import HOOKS, Hook
 
 
-@HOOKS.register_module
+@HOOKS.register_module()
 class DistSamplerSeedHook(Hook):
 
     def before_epoch(self, runner):
